==> spip_4.0.4.orig.tar.xz: plugins-dist/mots/lang/mots_ja.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=ja
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>重要グループ：</b> このグループからキーワードを選択することを強く勧めます。',
	'avis_doublon_mot_cle' => 'このキーワードのタイトルは既に存在します。 同じものをもう一度作成するのは構わないですか。',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'サイトの管理者',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => '著者',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => '公開サイトの訪問者が掲示板にメッセージを投稿したとき',

	// C
	'creer_et_associer_un_mot' => 'キーワードを作成して割り当てる',

	// I
	'icone_creation_groupe_mots' => '新規キーワードのグループを作成',
	'icone_creation_mots_cles' => '新規キーワードを作成',
	'icone_modif_groupe_mots' => 'このキーワードグループを編集',
	'icone_modifier_mot' => 'このキーワードを編集',
	'icone_mots_cles' => 'キーワード',
	'icone_supprimer_groupe_mots' => 'このグループを削除',
	'icone_voir_groupe_mots' => 'このグループを表示',
	'icone_voir_tous_mots_cles' => 'すべてのキーワードを表示',
	'info_1_groupe_mots' => 'キーワードのグループ１つ',
	'info_articles_lies_mot' => 'このキーワードに関連した記事',
	'info_aucun_groupe_mots' => 'キーワードのグループ無し',
	'info_aucun_mot_cle' => 'キーワード無し',
	'info_changer_nom_groupe' => 'このグループ名を編集する：',
	'info_creation_mots_cles' => 'このサイトのキーワードを作成して設定して下さい。',
	'info_dans_groupe' => 'グループの中に',
	'info_delet_mots_cles' => 'キーワード<b>@titre_mot@</b>（@type_mot@）の削除を求めました。このキーワードは<b>@texte_lie@</b>に繋がっているので、この決定を確認する必要があります：',
	'info_groupe_important' => '重要なグループ',
	'info_modifier_mot' => 'キーワードを編集：',
	'info_mots_cles' => 'キーワード',
	'info_mots_cles_association' => 'このグループのキーワードは次のものと関連付けることができます：',
	'info_nb_groupe_mots' => 'グループのキーワード@nb@件',
	'info_oui_suppression_mot_cle' => 'このキーワードを完全に削除することを望みます。',
	'info_question_mots_cles' => '公開サイトでキーワードを使用してほしいでか。',
	'info_qui_attribue_mot_cle' => '次の方は、このグループにキーワードを割り当てることが出来ます。',
	'info_remplacer_mot' => '「@titre@」を置き換える',
	'info_retirer_mot' => 'このキーワードを削除',
	'info_retirer_mots' => 'すべてのキーワードを削除',
	'info_rubriques_liees_mot' => 'このキーワードと関連してあるセクション',
	'info_selection_un_seul_mot_cle' => 'このグループでは、一度に<b>1つのキーワード</b>のみを選択出来ます。',
	'info_supprimer_mot' => 'このキーワードを削除',
	'info_titre_mot_cle' => 'このキーワードの名前',
	'info_un_mot' => '１度に１つのキーワードだけ',
	'item_ajout_mots_cles' => '掲示板へキーワードの追加を許可',
	'item_non_ajout_mots_cles' => '掲示板へのキーワードの追加を許可しない',
	'item_non_utiliser_config_groupe_mots_cles' => 'キーワードグループの拡張設定は使わない',
	'item_non_utiliser_mots_cles' => 'キーワードは使わない',
	'item_utiliser_config_groupe_mots_cles' => 'キーワードグループの拡張設定を使う',
	'item_utiliser_mots_cles' => 'キーワードを使う',

	// L
	'lien_ajouter_mot' => 'このキーワードを追加',
	'logo_groupe' => 'このグループのロゴ',
	'logo_mot_cle' => 'キーワードのロゴ',

	// T
	'texte_config_groupe_mots_cles' => 'キーワード用の拡張設定を有効にしますか？例えば、グループからただ1つのキーワードを使用するため、あるいは、グループの重要さを示すため。',
	'texte_mots_cles' => 'キーワードは記事の場所にかかわらず、あなたの記事と話題（キーワード）をくっつける事が出来ます。そのようにあなたのサイトで検索し易くするか、あなたのテンプレートで記事をカスタマイズするそれらの特性を使う。',
	'texte_mots_cles_dans_forum' => '公開フォーラムで訪問者がキーワードを選択できるようにしますか？（警告：このオプションを正しく使用するのは難しいです。）',
	'texte_nouveau_mot' => '新しいキーワード',
	'titre_config_groupe_mots_cles' => 'キーワードグループの設定',
	'titre_gauche_mots_edit' => 'キーワードの番号:',
	'titre_groupe_mots' => 'キーワードグループ',
	'titre_groupe_mots_numero' => 'キーワードグループの番号：',
	'titre_groupes_mots' => 'キーワードグループ',
	'titre_mots_cles_dans_forum' => '公開サイトの掲示板のキーワード',
	'titre_mots_tous' => 'キーワード',
	'titre_nouveau_groupe' => '新しいグループ',
	'titre_objets_lies_mot' => 'このキーワードに割り当てた項目：',
	'titre_page_mots_tous' => 'キーワード'
);

==> spip_4.4.5+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_ja.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=ja
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>重要グループ：</b> このグループからキーワードを選択することを強く勧めます。',
	'avis_doublon_mot_cle' => 'このキーワードのタイトルは既に存在します。 同じものをもう一度作成するのは構わないですか。',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'サイトの管理者',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => '著者',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => '公開サイトの訪問者が掲示板にメッセージを投稿したとき',

	// C
	'creer_et_associer_un_mot' => 'キーワードを作成して割り当てる',

	// I
	'icone_creation_groupe_mots' => '新規キーワードのグループを作成',
	'icone_creation_mots_cles' => '新規キーワードを作成',
	'icone_modif_groupe_mots' => 'このキーワードグループを編集',
	'icone_modifier_mot' => 'このキーワードを編集',
	'icone_mots_cles' => 'キーワード',
	'icone_supprimer_groupe_mots' => 'このグループを削除',
	'icone_voir_groupe_mots' => 'このグループを表示',
	'icone_voir_tous_mots_cles' => 'すべてのキーワードを表示',
	'info_1_groupe_mots' => 'キーワードのグループ１つ',
	'info_articles_lies_mot' => 'このキーワードに関連した記事',
	'info_aucun_groupe_mots' => 'キーワードのグループ無し',
	'info_aucun_mot_cle' => 'キーワード無し',
	'info_changer_nom_groupe' => 'このグループ名を編集する：',
	'info_creation_mots_cles' => 'このサイトのキーワードを作成して設定して下さい。',
	'info_dans_groupe' => 'グループの中に',
	'info_delet_mots_cles' => 'キーワード<b>@titre_mot@</b>（@type_mot@）の削除を求めました。このキーワードは<b>@texte_lie@</b>に繋がっているので、この決定を確認する必要があります：',
	'info_groupe_important' => '重要なグループ',
	'info_modifier_mot' => 'キーワードを編集：',
	'info_mots_cles' => 'キーワード',
	'info_mots_cles_association' => 'このグループのキーワードは次のものと関連付けることができます：',
	'info_nb_groupe_mots' => 'グループのキーワード@nb@件',
	'info_oui_suppression_mot_cle' => 'このキーワードを完全に削除することを望みます。',
	'info_question_mots_cles' => '公開サイトでキーワードを使用してほしいでか。',
	'info_qui_attribue_mot_cle' => '次の方は、このグループにキーワードを割り当てることが出来ます。',
	'info_remplacer_mot' => '「@titre@」を置き換える',
	'info_retirer_mot' => 'このキーワードを削除',
	'info_retirer_mots' => 'すべてのキーワードを削除',
	'info_rubriques_liees_mot' => 'このキーワードと関連してあるセクション',
	'info_selection_un_seul_mot_cle' => 'このグループでは、一度に<b>1つのキーワード</b>のみを選択出来ます。',
	'info_supprimer_mot' => 'このキーワードを削除',
	'info_titre_mot_cle' => 'このキーワードの名前',
	'info_un_mot' => '１度に１つのキーワードだけ',
	'item_ajout_mots_cles' => '掲示板へキーワードの追加を許可',
	'item_non_ajout_mots_cles' => '掲示板へのキーワードの追加を許可しない',
	'item_non_utiliser_config_groupe_mots_cles' => 'キーワードグループの拡張設定は使わない',
	'item_non_utiliser_mots_cles' => 'キーワードは使わない',
	'item_utiliser_config_groupe_mots_cles' => 'キーワードグループの拡張設定を使う',
	'item_utiliser_mots_cles' => 'キーワードを使う',

	// L
	'lien_ajouter_mot' => 'このキーワードを追加',
	'logo_groupe' => 'このグループのロゴ',
	'logo_mot_cle' => 'キーワードのロゴ',

	// T
	'texte_config_groupe_mots_cles' => 'キーワード用の拡張設定を有効にしますか？例えば、グループからただ1つのキーワードを使用するため、あるいは、グループの重要さを示すため。',
	'texte_mots_cles' => 'キーワードは記事の場所にかかわらず、あなたの記事と話題（キーワード）をくっつける事が出来ます。そのようにあなたのサイトで検索し易くするか、あなたのテンプレートで記事をカスタマイズするそれらの特性を使う。',
	'texte_mots_cles_dans_forum' => '公開フォーラムで訪問者がキーワードを選択できるようにしますか？（警告：このオプションを正しく使用するのは難しいです。）',
	'texte_nouveau_mot' => '新しいキーワード',
	'titre_config_groupe_mots_cles' => 'キーワードグループの設定',
	'titre_gauche_mots_edit' => 'キーワードの番号:',
	'titre_groupe_mots' => 'キーワードグループ',
	'titre_groupe_mots_numero' => 'キーワードグループの番号：',
	'titre_groupes_mots' => 'キーワードグループ',
	'titre_mots_cles_dans_forum' => '公開サイトの掲示板のキーワード',
	'titre_mots_tous' => 'キーワード',
	'titre_nouveau_groupe' => '新しいグループ',
	'titre_objets_lies_mot' => 'このキーワードに割り当てた項目：',
	'titre_page_mots_tous' => 'キーワード',
];
